package Daje::Database::View::VTreeList;
use Mojo::Base 'Daje::Database::View::Super::VTreeList', -base, -signatures;
use v5.40;


1;
#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME

Daje::Database::View::VTreeList


=head1 REQUIRES

L<v5.40> 

L<Mojo::Base> 


=head1 METHODS


=cut

