package Daje::Database::Model::Super::ToolsTreelist;
use Mojo::Base 'Daje::Database::Model::Super::Common::Base', -base, -signatures, -async_await;;

1;
#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME

Daje::Database::Model::Super::ToolsTreelist


=head1 REQUIRES

L<Mojo::Base> 


=head1 METHODS


=cut

