package Daje::Database::View::VToolsObjectsTables;
use Mojo::Base 'Daje::Database::View::Super::VToolsObjectsTables', -base, -signatures, -async_await;
use v5.40;

# NAME
# ====
#
# Daje::Database::View::VToolsObjects - It creates perl code
#
# SYNOPSIS
# ========
#
#     use Daje::Database::View::VToolsObjects;
#
# DESCRIPTION
# ===========
#
# Daje::Database::View::VToolsObjects is a module that retrieves data from a View
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.comE<gt>
#


1;
#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME


Daje::Database::View::VToolsObjects - It creates perl code



=head1 SYNOPSIS


    use Daje::Database::View::VToolsObjects;



=head1 DESCRIPTION


Daje::Database::View::VToolsObjects is a module that retrieves data from a View



=head1 REQUIRES

L<v5.40> 

L<Mojo::Base> 


=head1 METHODS


=head1 AUTHOR


janeskil1525 E<lt>janeskil1525@gmail.comE<gt>



=head1 LICENSE


Copyright (C) janeskil1525.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.



=cut

